==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbquery_test/loadtransfers_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadTransfers(t *testing.T) {
	testCases := []struct {
		Test               string
		MockGTFS           map[int]string
		Sources            []int
		MinTransferSeconds uint
		MaxTransferSeconds uint
		WalkspeedKmHr      float64
		TransferCategories []string
		ExpectTransfers    []dbt.Transfer
	}{
		{
			Test:               "Works with feed provided transfers.txt (for both min_transfer_time & dynamic dist calc)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			Sources:            []int{42},
			MinTransferSeconds: 0,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"f"},
			ExpectTransfers: []dbt.Transfer{
				// FromSource, FromSSIDU, FromStopIDU, FromStopID, ToSource, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_b", "station_b", "station_b", "f", 3},
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_c", "station_c", "station_c", "f", 46},
			},
		},
		{
			Test:               "Works with implicit transfers",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			Sources:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"i"},
			ExpectTransfers: []dbt.Transfer{
				// FromSource, FromSSIDU, FromStopIDU, FromStopID, ToSource, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_a", "station_a", "station_a", "i", 3},
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_b", "station_b", "station_b", "i", 3},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_c", "station_c", "station_c", "i", 3},
			},
		},
		{
			Test:               "Works with generated transfers",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			Sources:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"g"},
			ExpectTransfers: []dbt.Transfer{
				// FromSource, FromSSIDU, FromStopIDU, FromStopID, ToSource, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_a", "station_a", "station_a", "g", 15},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_a", "station_a", "station_a", "g", 46},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_b", "station_b", "station_b", "g", 57},
			},
		},
		{
			Test:               "Works with a combination of transfer types (feed & generated)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			Sources:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"f", "g"},
			ExpectTransfers: []dbt.Transfer{
				// FromSource, FromSSIDU, FromStopIDU, FromStopID, ToSource, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_a", "station_a", "station_a", "g", 15},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_a", "station_a", "station_a", "g", 46},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_b", "station_b", "station_b", "g", 57},

				{42, "42_station_a", "station_a", "station_a", 42, "42_station_b", "station_b", "station_b", "f", 3},
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_c", "station_c", "station_c", "f", 46},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if transfers, err := dbquery.LoadTransfers(
			sqlxDB,
			testCase.Sources, testCase.MinTransferSeconds, testCase.MaxTransferSeconds,
			testCase.WalkspeedKmHr, testCase.TransferCategories,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectTransfers, *transfers) {
			t.Fatalf(
				"LoadTransfers Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectTransfers, *transfers, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/dbquery_test/loadtransfers_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadTransfers(t *testing.T) {
	testCases := []struct {
		Test               string
		MockGTFS           map[int]string
		FeedIDs            []int
		MinTransferSeconds uint
		MaxTransferSeconds uint
		WalkspeedKmHr      float64
		TransferCategories []string
		ExpectTransfers    []dbt.Transfer
	}{
		{
			Test:               "Works with feed provided transfers.txt (for both min_transfer_time & dynamic dist calc)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			FeedIDs:            []int{42},
			MinTransferSeconds: 0,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"f"},
			ExpectTransfers: []dbt.Transfer{
				// FromFeedID, FromSSIDU, FromStopIDU, FromStopID, ToFeedID, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_b", "station_b", "station_b", "f", 3},
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_c", "station_c", "station_c", "f", 46},
			},
		},
		{
			Test:               "Works with implicit transfers",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			FeedIDs:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"i"},
			ExpectTransfers: []dbt.Transfer{
				// FromFeedID, FromSSIDU, FromStopIDU, FromStopID, ToFeedID, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_a", "station_a", "station_a", "i", 3},
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_b", "station_b", "station_b", "i", 3},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_c", "station_c", "station_c", "i", 3},
			},
		},
		{
			Test:               "Works with generated transfers",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			FeedIDs:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"g"},
			ExpectTransfers: []dbt.Transfer{
				// FromFeedID, FromSSIDU, FromStopIDU, FromStopID, ToFeedID, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_a", "station_a", "station_a", "g", 15},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_a", "station_a", "station_a", "g", 46},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_b", "station_b", "station_b", "g", 57},
			},
		},
		{
			Test:               "Works with a combination of transfer types (feed & generated)",
			MockGTFS:           map[int]string{42: "../testhelper/mockgtfs/gtfs_transfers.yml"},
			FeedIDs:            []int{42},
			MinTransferSeconds: 3,
			MaxTransferSeconds: 1000,
			WalkspeedKmHr:      3.5,
			TransferCategories: []string{"f", "g"},
			ExpectTransfers: []dbt.Transfer{
				// FromFeedID, FromSSIDU, FromStopIDU, FromStopID, ToFeedID, ToSSIDU, ToStopIDU, ToStopID, TransferCategory, TransferSeconds
				{42, "42_station_b", "station_b", "station_b", 42, "42_station_a", "station_a", "station_a", "g", 15},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_a", "station_a", "station_a", "g", 46},
				{42, "42_station_c", "station_c", "station_c", 42, "42_station_b", "station_b", "station_b", "g", 57},

				{42, "42_station_a", "station_a", "station_a", 42, "42_station_b", "station_b", "station_b", "f", 3},
				{42, "42_station_a", "station_a", "station_a", 42, "42_station_c", "station_c", "station_c", "f", 46},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if transfers, err := dbquery.LoadTransfers(
			sqlxDB,
			testCase.FeedIDs, testCase.MinTransferSeconds, testCase.MaxTransferSeconds,
			testCase.WalkspeedKmHr, testCase.TransferCategories,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectTransfers, *transfers) {
			t.Fatalf(
				"LoadTransfers Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectTransfers, *transfers, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}
